@@ -154,6 +154,19 @@ typedef struct reg
     struct reg	*reg_next;	/* Next region in list */
 } ExtRegion;
 
+    /*
+     * Special structure for split tiles which have something other than
+     * TT_SPACE on both sides and require two regions to represent both
+     * nets connected to the tile.
+     */
+typedef struct split_reg
+{
+    ExtRegion *reg_guard;	// Use this to guard against failure to
+				// identify a split region (temporary).
+    ExtRegion *reg_left;	// Region belonging to tile left side
+    ExtRegion *reg_right;	// Region belonging to tile right side
+} ExtSplitRegion;
+
     /*
      * GENERIC region with labels.
      * Any other structure that wants to reference node names
@@ -212,16 +225,18 @@ typedef struct treg
 {
     struct treg	*treg_next;	/* Next region in list */
     int		 treg_pnum;	/* UNUSED */
-    int		 treg_type;	/* Type of tile that contains treg_ll */
+    int		 treg_type;	/* UNUSED */
     Point	 treg_ll;	/* UNUSED */
     LabelList	*treg_labels;	/* Attribute list */
     Tile	*treg_tile;	/* Some tile in the channel */
+    TileType	 treg_dinfo;	/* Diagonal information for treg_tile* */
     int		 treg_area;	/* Area of channel */
 } TransRegion;
 
 typedef struct {	/* Maintain plane information when pushing	*/
     Rect area;		/* tiles on the node stack.  For use with	*/
     int  plane;		/* function extNbrPushFunc().			*/
+    ClientData uninit;	/* Value of an unvisited region			*/
 } PlaneAndArea;
 
 /* Structure to be kept in a hash table of node regions for the current	*/
@@ -253,7 +268,7 @@ typedef struct
     CellDef		*fra_def;	 /* Def being searched */
     int			 fra_pNum;	 /* Plane currently searching */
     ClientData		 fra_uninit;	 /* This value appears in the ti_client
-					  * field of a tile if it's not yet
+					  * field of a tile if it has not yet
 					  * been visited.
 					  */
     ExtRegion	      *(*fra_first)();	 /* Function to init new region */
@@ -281,16 +296,27 @@ typedef struct
     int		 b_plane;	/* extract argument for extSideOverlap   */
 } Boundary;
 
+/* Define Manhattan boundary length */
+
 #define	BoundaryLength(bp) \
 	((bp)->b_segment.r_xtop - (bp)->b_segment.r_xbot \
     +    (bp)->b_segment.r_ytop - (bp)->b_segment.r_ybot)
 
 /* Directions in which we can be following the boundary of a perimeter	*/
 
-#define	BD_LEFT		1	/* Inside is to right */
-#define	BD_TOP		2	/* Inside is below */
-#define	BD_RIGHT	4	/* Inside is to left */
-#define	BD_BOTTOM	8	/* Inside is above */
+#define	BD_LEFT		0x01	/* Inside is to right */
+#define	BD_TOP		0x02	/* Inside is below */
+#define	BD_RIGHT	0x04	/* Inside is to left */
+#define	BD_BOTTOM	0x08	/* Inside is above */
+
+/* Non-manhattan boundary directions.  Inside is in the
+ * direction indicated (e.g., BD_NW, inside is top left)
+ */
+#define BD_NW		0x10	/* TT_SIDE = 0 TT_DIR = 0 */
+#define BD_SW		0x20	/* TT_SIDE = 0 TT_DIR = 1 */
+#define BD_SE		0x40	/* TT_SIDE = 1 TT_DIR = 0 */
+#define BD_NE		0x80	/* TT_SIDE = 1 TT_DIR = 1 */
+
 
 /* -------- Yank buffers for hierarchical and array extraction -------- */
 
@@ -342,6 +368,7 @@ typedef struct extTree
      *	char *
      *	proc(tp, et, ha)
      *	    Tile *tp;
+     *	    TileType dinfo;
      *	    ExtTree *et;
      *	    HierExtractArg *ha;
      *	{
@@ -372,7 +399,7 @@ typedef struct
 				 */
     Tile	*hierOneTile;	/* Used in ExtHier.c, tile from extHierOneFlat */
     int		hierPNum;	/* Used in ExtHier.c, plane of tile above */
-    TileType	hierType;	/* Used in ExtHier.c, type of tile above */
+    TileType	hierType;	/* Used in ExtHier.c, type of tile above, incl. TT_SIDE */
     int		hierPNumBelow;	/* Used in ExtHier.c, plane of tile below */
 } HierExtractArg;
 
@@ -934,12 +961,6 @@ extern ExtStyle *ExtCurStyle;
 
 /* ------------------- Hierarchical node merging ---------------------- */
 
-/*
- * Table used to hold all merged nodes during hierarchical extraction.
- * Used for duplicate suppression.
- */
-extern HashTable extHierMergeTable;
-
 /*
  * Each hash entry in the above table points to a NodeName struct.
  * Each NodeName points to the Node corresponding to that name.
@@ -968,17 +989,10 @@ typedef struct node
 
 /* -------------------------------------------------------------------- */
 
-/*
- * Value normally resident in the ti_client field of a tile,
- * indicating that the tile has not yet been visited in a
- * region search.
- */
-extern ClientData extUnInit;
+extern ExtRegion *ExtGetRegion(Tile *tile, TileType dinfo);
 
-#define extGetRegion(tp)	( (tp)->ti_client )
 #define extHasRegion(tp,und)	( (tp)->ti_client != (und) )
 
-
 /* For non-recursive flooding algorithm */
 #define	VISITPENDING	((ClientData) NULL)	/* Marks tiles on stack */
 
@@ -989,44 +1003,47 @@ extern ClientData extUnInit;
 /* because the search algorithm can overwrite it between the	*/
 /* time the tile is pushed and the time that it is popped.	*/
 
-#define	PUSHTILE(tp, pl) \
-	(tp)->ti_client = VISITPENDING; \
-	STACKPUSH((ClientData)(pointertype)(pl | \
-		((TileType)(spointertype)(tp)->ti_body & TT_SIDE)), extNodeStack); \
+#define	PUSHTILE(tp, di, pl) \
+	ExtSetRegion(tp, di, (ExtRegion *)VISITPENDING); \
+	STACKPUSH((ClientData)(pointertype)pl, extNodeStack); \
+	STACKPUSH((ClientData)(pointertype)di, extNodeStack); \
 	STACKPUSH((ClientData)(pointertype)tp, extNodeStack)
 
-#define POPTILE(tp, pl) \
+#define POPTILE(tp, di, pl) \
 	tp = (Tile *) STACKPOP(extNodeStack); \
-	pl = (spointertype) STACKPOP(extNodeStack); \
-	if (pl & TT_SIDE) { \
-	   TiSetBody((tp), TiGetTypeExact(tp) | TT_SIDE); \
-	   pl &= (~TT_SIDE); \
-	} \
-	else \
-	   TiSetBody((tp), TiGetTypeExact(tp) & (~TT_SIDE))
+	di = (spointertype) STACKPOP(extNodeStack); \
+	pl = (spointertype) STACKPOP(extNodeStack)
 
 /* Variations of "pushtile" to force a specific value on TT_SIDE */
 
 #define PUSHTILEBOTTOM(tp, pl) \
-	(tp)->ti_client = VISITPENDING; \
-	STACKPUSH((ClientData)(pointertype)(pl | \
-		((SplitDirection(tp)) ? 0 : TT_SIDE)), extNodeStack) ;\
-	STACKPUSH((ClientData)(pointertype)tp, extNodeStack)
+	{ \
+	TileType di = (SplitDirection(tp)) ? 0 : TT_SIDE; \
+	ExtSetRegion(tp, di, (ExtRegion *)VISITPENDING); \
+	STACKPUSH((ClientData)(pointertype)pl, extNodeStack); \
+	STACKPUSH((ClientData)(pointertype)di, extNodeStack); \
+	STACKPUSH((ClientData)(pointertype)tp, extNodeStack); \
+	}
 
 #define PUSHTILETOP(tp, pl) \
-	(tp)->ti_client = VISITPENDING; \
-	STACKPUSH((ClientData)(pointertype)(pl | \
-		((SplitDirection(tp)) ? TT_SIDE : 0)), extNodeStack) ;\
-	STACKPUSH((ClientData)(pointertype)tp, extNodeStack)
+	{ \
+	TileType di = (SplitDirection(tp)) ? TT_SIDE : 0; \
+	ExtSetRegion(tp, di, (ExtRegion *)VISITPENDING); \
+	STACKPUSH((ClientData)(pointertype)pl, extNodeStack); \
+	STACKPUSH((ClientData)(pointertype)di, extNodeStack); \
+	STACKPUSH((ClientData)(pointertype)tp, extNodeStack); \
+	}
 
 #define PUSHTILELEFT(tp, pl) \
-	(tp)->ti_client = VISITPENDING; \
+	ExtSetRegion(tp, (TileType)0, (ExtRegion *)VISITPENDING); \
 	STACKPUSH((ClientData)(pointertype)(pl), extNodeStack); \
+	STACKPUSH((ClientData)(pointertype)0, extNodeStack); \
 	STACKPUSH((ClientData)(pointertype)tp, extNodeStack)
 
 #define PUSHTILERIGHT(tp, pl) \
-	(tp)->ti_client = VISITPENDING; \
-	STACKPUSH((ClientData)(pointertype)(pl | TT_SIDE), extNodeStack); \
+	ExtSetRegion(tp, (TileType)TT_SIDE, (ExtRegion *)VISITPENDING); \
+	STACKPUSH((ClientData)(pointertype)pl, extNodeStack); \
+	STACKPUSH((ClientData)(pointertype)TT_SIDE, extNodeStack); \
 	STACKPUSH((ClientData)(pointertype)tp, extNodeStack)
 
 /* ------------------------- Region finding --------------------------- */
@@ -1056,11 +1073,12 @@ extern Tile *extNodeToTile();
 #define	NODETONODE(nold, et, nnew) \
 	if (1) { \
 	    Tile *tp; \
+	    TileType di; \
  \
 	    (nnew) = (NodeRegion *) NULL; \
-	    tp = extNodeToTile((nold), (et)); \
-	    if (tp && extHasRegion(tp, extUnInit)) \
-		(nnew) = (NodeRegion *) extGetRegion(tp); \
+	    tp = extNodeToTile((nold), (et), (TileType *)&di); \
+	    if (tp && extHasRegion(tp, CLIENTDEFAULT)) \
+		(nnew) = (NodeRegion *) ExtGetRegion(tp, di); \
 	}
 
 /* -------------------- Miscellaneous procedures ---------------------- */
@@ -1072,6 +1090,7 @@ extern ExtTree *extHierNewOne();
 extern int extNbrPushFunc();
 extern TileType extGetDevType();
 extern void extMakeNodeNumPrint();
+extern void ExtSetRegion();
 
 /* --------------------- Miscellaneous globals ------------------------ */
 
@@ -1104,6 +1123,10 @@ extern Plane *extCellFile();
 extern int  extInterAreaFunc();
 extern int  extTreeSrPaintArea();
 extern int  extMakeUnique();
+extern void extEnumTerminal();
+extern void extEnumTerminal(Tile *tile, TileType dinfo,
+        TileTypeBitMask *connect, void (*func)(), ClientData clientData);
+
 
 /* ------------------ Connectivity table management ------------------- */
 
