@@ -26,10 +26,13 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/
 #include <stdlib.h>
 #include <string.h>
 #include <strings.h>
+#include <unistd.h>
 
 #include <sys/types.h>
 #include <sys/times.h>
+#ifdef HAVE_SYS_TIME_H
 #include <sys/time.h>
+#endif
 
 #include "tcltk/tclmagic.h"
 #include "utils/main.h"
@@ -73,7 +76,9 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/
 #ifdef ROUTE_MODULE
 #include "mzrouter/mzrouter.h"
 #endif
+#ifdef SCHEME_INTERPRETER
 #include "lisp/lisp.h"
+#endif
 #ifdef THREE_D
 #include "graphics/wind3d.h"
 #endif
